/**
 * @file config.h
 *
 * @brief @{Header file that enables/disables various CCG firmware features.
 *
 * This file also provides mapping to the implementation for hardware dependent
 * functions like FET control, voltage selection etc.
 *
 * This current implementation matches the CCG4M reference board from Cypress. This
 * can be updated by users to match their hardware implementation.@}
 *
 *******************************************************************************
 *
 * Copyright (2014-2017), Cypress Semiconductor Corporation or a subsidiary of
 * Cypress Semiconductor Corporation. All rights reserved.
 *
 * This software, including source code, documentation and related materials
 * (“Software”), is owned by Cypress Semiconductor Corporation or one of its
 * subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
 * protection (United States and foreign), United States copyright laws and
 * international treaty provisions. Therefore, you may use this Software only
 * as provided in the license agreement accompanying the software package from
 * which you obtained this Software (“EULA”).
 *
 * If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
 * non-transferable license to copy, modify, and compile the Software source
 * code solely for use in connection with Cypress’s integrated circuit
 * products. Any reproduction, modification, translation, compilation, or
 * representation of this Software except as specified above is prohibited
 * without the express written permission of Cypress. Disclaimer: THIS SOFTWARE
 * IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the
 * right to make changes to the Software without notice. Cypress does not
 * assume any liability arising out of the application or use of the Software
 * or any product or circuit described in the Software. Cypress does not
 * authorize its products for use in any products where a malfunction or
 * failure of the Cypress product may reasonably be expected to result in
 * significant property damage, injury or death (“High Risk Product”). By
 * including Cypress’s product in a High Risk Product, the manufacturer of such
 * system or application assumes all risk of such use and in doing so agrees to
 * indemnify Cypress against all liability.
 */
#ifndef _CONFIG_H_
#define _CONFIG_H_

/*******************************************************************************
 * Header files including
 ******************************************************************************/
#include <project.h>
#include <stack_params.h>

/*******************************************************************************
 * PSOURCE controls for PD port 1.
 * The current implementation corresponds to the CCG4M reference board. Please
 * update this as required to match the target hardware.
 ******************************************************************************/

/* Function/Macro to turn power source for P1 ON. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SRC_FET_ON_P1()                    pd_internal_pfet_on(0, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SRC_FET_ON_P1()                    VBUS_P_CTRL_P1_Write(1)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn power source for P1 OFF. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SRC_FET_OFF_P1()                   pd_internal_pfet_off(0, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SRC_FET_OFF_P1()                   VBUS_P_CTRL_P1_Write(0)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn VBUS_DISCHARGE FET for P1 ON. */
#define APP_DISCHARGE_FET_ON_P1()                   VBUS_DISCHARGE_P1_Write(1)

/* Function/Macro to turn VBUS_DISCHARGE FET for P1 OFF. */
#define APP_DISCHARGE_FET_OFF_P1()                  VBUS_DISCHARGE_P1_Write(0)

/* Function/Macro to set P1 source voltage to 5V. Nothing to do. */
#define APP_VBUS_SET_5V_P1()                        __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 9V. Not supported. */
#define APP_VBUS_SET_9V_P1()                        __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 12V. Not supported. */
#define APP_VBUS_SET_12V_P1()                       __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 13V. Not supported. */
#define APP_VBUS_SET_13V_P1()                       __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 15V. Not supported. */
#define APP_VBUS_SET_15V_P1()                       __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 19V. Not supported. */
#define APP_VBUS_SET_19V_P1()                       __asm("NOP\n")

/* Function/Macro to set P1 source voltage to 20V. Not supported. */
#define APP_VBUS_SET_20V_P1()                       __asm("NOP\n")

/*******************************************************************************
 * PSOURCE controls for PD port 2.
 * The current implementation corresponds to the CCG4M reference board. Please
 * update this as required to match the target hardware.
 ******************************************************************************/

/* Function/Macro to turn power source for P2 ON. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SRC_FET_ON_P2()                    pd_internal_pfet_on(1, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SRC_FET_ON_P2()                    VBUS_P_CTRL_P2_Write(1)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn power source for P2 OFF. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SRC_FET_OFF_P2()                   pd_internal_pfet_off(1, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SRC_FET_OFF_P2()                   VBUS_P_CTRL_P2_Write(0)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn VBUS_DISCHARGE FET for P2 ON. */
#define APP_DISCHARGE_FET_ON_P2()                   VBUS_DISCHARGE_P2_Write(1)

/* Function/Macro to turn VBUS_DISCHARGE FET for P2 OFF. */
#define APP_DISCHARGE_FET_OFF_P2()                  VBUS_DISCHARGE_P2_Write(0)

/* Function/Macro to set P2 source voltage to 5V. Nothing to do. */
#define APP_VBUS_SET_5V_P2()                        __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 9V. Not supported. */
#define APP_VBUS_SET_9V_P2()                        __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 12V. Not supported. */
#define APP_VBUS_SET_12V_P2()                       __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 13V. Not supported. */
#define APP_VBUS_SET_13V_P2()                       __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 15V. Not supported. */
#define APP_VBUS_SET_15V_P2()                       __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 19V. Not supported. */
#define APP_VBUS_SET_19V_P2()                       __asm("NOP\n")

/* Function/Macro to set P2 source voltage to 20V. Not supported. */
#define APP_VBUS_SET_20V_P2()                       __asm("NOP\n")

/*******************************************************************************
 * Power Sink (PSINK) controls for PD port 1.
 * The current implementation corresponds to the CCG4M reference board. Please
 * update this as required to match the target hardware.
 ******************************************************************************/

/* Function/Macro to turn consumer FET for P1 ON. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SNK_FET_ON_P1()                    pd_internal_cfet_on(0, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SNK_FET_ON_P1()                    VBUS_C_CTRL_P1_Write(1)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn consumer FET for P1 OFF. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SNK_FET_OFF_P1()                   pd_internal_cfet_off(0, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SNK_FET_OFF_P1()                   VBUS_C_CTRL_P1_Write(0)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/*******************************************************************************
 * Power Sink (PSINK) controls for PD port 2.
 * The current implementation corresponds to the CCG4M reference board. Please
 * update this as required to match the target hardware.
 ******************************************************************************/

/* Function/Macro to turn consumer FET for P2 ON. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SNK_FET_ON_P2()                    pd_internal_cfet_on(1, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SNK_FET_ON_P2()                    VBUS_C_CTRL_P2_Write(1)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/* Function/Macro to turn consumer FET for P2 OFF. */
#if (VBUS_FET_INTERNAL_CTRL)
#define APP_VBUS_SNK_FET_OFF_P2()                   pd_internal_cfet_off(1, false)
#else /* (VBUS_FET_INTERNAL_CTRL) */
#define APP_VBUS_SNK_FET_OFF_P2()                   VBUS_C_CTRL_P2_Write(0)
#endif /* (VBUS_FET_INTERNAL_CTRL) */

/*******************************************************************************
 * VBus Monitoring Controls for detach detection.
 ******************************************************************************/

/* Division factor applied between VBus and the voltage on VBUS_MON input. */
#define VBUS_MON_DIVIDER                            (11u)

/*******************************************************************************
 * VBus Over-Current Protection Configuration.
 *
 * The VBus OCP feature is implemented based on an external load switch and
 * only uses a fault indicator GPIO coming into the CCG device.
 ******************************************************************************/

/*
 * VBus OCP feature enable. Requires external load switch on CCG4 and CCG4M devices.
 * Disabled because CCG4M reference board does not have this.
 */
#define VBUS_OCP_ENABLE                             (0u)

/*******************************************************************************
 * VBus Over-Voltage Protection Configuration.
 *
 * The VBus OVP feature uses an internal ADC in the CCG to measure the voltage
 * on the VBUS_MON input and uses the ADC output to detect over-voltage
 * conditions.
 *
 * The default implementation of OVP uses firmware ISRs to turn off the FETs
 * when OVP is detected. If quicker response is desired, there is the option of
 * using a direct OVP_TRIP output derived from a hardware comparator associated
 * with the ADC.
 ******************************************************************************/

/* VBus OVP enable setting. */
#define VBUS_OVP_ENABLE                             (1u)

/* Allowed over-voltage margin as percentage of nominal voltage. */
#define VBUS_OVP_MARGIN                             (20)

/* Enable direct OVP_TRIP output from hardware comparator. */
#define VBUS_OVP_TRIP_ENABLE                        (1u)

/*******************************************************************************
 * VConn Over-Current Protection Configuration.
 *
 * The VConn OCP feature is implemented based on an external load switch and
 * only uses a fault indicator GPIO coming into the CCG device.
 ******************************************************************************/
/* VConn OCP enable setting. */
#define VCONN_OCP_ENABLE                            (0u)

/*******************************************************************************
 * Firmware feature configuration.
 ******************************************************************************/

/*
 * Index of SCB used for HPI interface. This should be set based on
 * the pin selection in the project schematic.
 */
#define HPI_SCB_INDEX                               (0u)

/* Set to 1 if building a debug enabled binary with no boot-loader dependency. */
#define CCG_FIRMWARE_APP_ONLY                       (0u)

/* Enable CCG deep sleep to save power. */
#define SYS_DEEPSLEEP_ENABLE                        (1u)

/* Enable Alternate Mode support when CCG is DFP. */
#define DFP_ALT_MODE_SUPP                           (1u)

/* Enable DisplayPort Source support as DFP. */
#define DP_DFP_SUPP                                 (1u)

/* Enable saving only SVIDs which are supported by CCG. */
#define SAVE_SUPP_SVID_ONLY                         (1u)

/*
 * Enable/Disable firmware active LED operation.
 *
 * No LED present on CCG4M reference board.
 */
#define APP_FW_LED_ENABLE                           (0u)

/*
 * Select CCG4 GPIO to be used as Activity Indication. This should be set to a
 * valid value if APP_FW_LED_ENABLE is non-zero.
 */
#define FW_LED_GPIO_PORT_PIN                        (GPIO_PORT_1_PIN_1)

/*
 * Timer ID allocation for various solution soft timers.
 */

/*
 * Activity indicator LED timer. The timer is used to indicate that the firmware
 * is functional. The feature is controlled by APP_FW_LED_ENABLE.
 */
#define LED_TIMER_ID                                (0xC0u)
/*
 * The LED toggle period.
 */
#define LED_TIMER_PERIOD                            (1000)

/* Timer used to ensure I2C transfers to the MUX complete on time. */
#define MUX_I2C_TIMER                               (0xC1u)
/* The MUX transfer timeout is set to 10 ms timeout period. */
#define MUX_I2C_TIMER_PERIOD                        (10u)

/************************************************/

/* Disable CCG device reset on error (watchdog expiry or hard fault). */
#define RESET_ON_ERROR_ENABLE                       (0u)

/* Watchdog reset timer id. */
#define WATCHDOG_TIMER_ID                           (0xC2u)

/*
 * Watchdog reset period in ms. This should be set to a value greater than
 * 500 ms to avoid significant increase in power consumption.
 */
#define WATCHDOG_RESET_PERIOD_MS                    (750u)

#endif /* _CONFIG_H_ */

/* End of file */
